@@ -424,6 +424,13 @@ DataSet
     return !(*this == other);
 }
 
+void
+DataSet
+::clear()
+{
+    this->_elements.clear();
+}
+
 void
 DataSet
 ::clear(Tag const & tag)
