@@ -19,11 +19,19 @@ namespace message
 {
 
 NCreateRequest
-::NCreateRequest(Value::Integer message_id, const Value::String &affected_sop_class_uid)
+::NCreateRequest(
+    Value::Integer message_id, const Value::String &affected_sop_class_uid, 
+    DataSet const & dataset)
 : Request(message_id)
 {
     this->set_command_field(Command::N_CREATE_RQ);
-    this->set_affected_sop_class_uid( affected_sop_class_uid ) ;
+    this->set_affected_sop_class_uid(affected_sop_class_uid);
+
+    if(dataset.empty())
+    {
+        throw Exception("Data set is required");
+    }
+    this->set_data_set(dataset);
 }
 
 NCreateRequest
@@ -38,6 +46,16 @@ NCreateRequest
 
     this->set_affected_sop_class_uid(
         message.get_command_set().as_string( registry::AffectedSOPClassUID, 0));
+
+    ODIL_MESSAGE_SET_OPTIONAL_FIELD_MACRO(
+        message.get_command_set(), affected_sop_instance_uid,
+        registry::AffectedSOPInstanceUID, as_string)
+
+    if(!message.has_data_set() || message.get_data_set().empty())
+    {
+        throw Exception("Data set is required");
+    }
+    this->set_data_set(message.get_data_set());
 }
 
 NCreateRequest
