@@ -9,16 +9,26 @@
 #ifndef _61eb6ed2_447a_43b5_a6ba_ca7c2a5fb492
 #define _61eb6ed2_447a_43b5_a6ba_ca7c2a5fb492
 
+#include <functional>
+#include <utility>
+
 #include <boost/property_tree/ptree.hpp>
 
 #include "odil/DataSet.h"
+
 #include "odil/odil.h"
 
 namespace odil
 {
 
+typedef
+    std::function<std::pair<std::string, std::string>(DataSet const &, Tag const &)>
+    BulkDataCreator;
+
 /// @brief Convert a data set to its XML representation.
-ODIL_API boost::property_tree::ptree as_xml(DataSet const & data_set);
+ODIL_API boost::property_tree::ptree as_xml(
+    DataSet const & data_set,
+    BulkDataCreator const & bulk_data_creator=BulkDataCreator());
 
 /// @brief Create a data set from its XML representation.
 ODIL_API DataSet as_dataset(boost::property_tree::ptree const & xml);
